/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit;

import org.tagunit.taginfo.TagInfo;

/**
 * The test context from which all tests for a specific tag are executed.
 *
 * @author    Simon Brown
 */
public class TagTestContext extends DefaultTestContextContainer {

  /** information about the tag being tested */
  private TagInfo tagInfo;

  /**
   * Default, no args constructor.
   */
  public TagTestContext() {
  }

  /**
   * Creates a new TagTestContext with the specified name.
   *
   * @param name    the name of the context
   */
  public TagTestContext(String name) {
    super(name);
  }

  /**
   * Setter for the information about the tag being tested.
   *
   * @return  a TagInfo object representing the tag
   */
  public TagInfo getTagInfo() {
    return tagInfo;
  }

  /**
   * Setter for the information about the tag being tested.
   *
   * @param tagInfo   a reference to a TagImfo object
   */
  public void setTagInfo(TagInfo tagInfo) {
    this.tagInfo = tagInfo;
  }

}