/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit;

/**
 * Represents a flattened TestContext - a wrapper for a TestContext and a level. A
 * level of zero indicates the root, one its children, two their children, etc.
 *
 * @author    Simon Brown
 */
public class TestResult {

  /** the actual TestContext represented here */
  private TestContext testContext;

  /** the level of the TestContext in the tree */
  private int level = 0;

  /**
   * Default, no args constructor.
   */
  public TestResult() {
  }

  /**
   * Creates a FlatTestContext.
   *
   * @param testContext   the actual TestContext instance
   * @param level       the level of the TestContext in the tree
   */
  public TestResult(TestContext testContext, int level) {
    this.testContext = testContext;
    this.level = level;
  }

  /**
   * Sets the associated TestContext.
   *
   * @param testContext   a TestContext instance
   */
  public void setTestContext(TestContext testContext) {
    this.testContext = testContext;
  }

  /**
   * Gets the associated TestContext.
   *
   * @return  a TestContext instance
   */
  public TestContext getTestContext() {
    return this.testContext;
  }

  /**
   * Sets the level of the TestContext.
   *
   * @param level   an integer
   */
  public void setLevel(int level) {
    this.level = level;
  }

  /**
   * Gets the level of the TestContext.
   *
   * @return  an integer
   */
  public int getLevel() {
    return this.level;
  }

}