/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.controller;

import java.io.*;
import java.util.*;

import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpServletResponseWrapper;

/**
 * This is a simple wrapper, used to wrap up the actual ServletResponse so that
 * content never gets written to the output stream, and headers are never
 * set. This is necessary because we don't want tags actually outputting
 * content back to the browser. Instead we want to capture it, run the tests
 * and then output the results, without all of the content that would
 * otherwise be output.
 *
 * @author      Simon Brown
 */
public class TestHttpServletResponseWrapper extends HttpServletResponseWrapper {

  private CharArrayWriter buffer;
  private PrintWriter writer;

  private Map headers;
  private int status;
  private int contentLength;
  private String contentType;
  private Locale locale;
  private String redirect;

  public TestHttpServletResponseWrapper(HttpServletResponse httpServletResponse) {
    super(httpServletResponse);

    this.buffer = new CharArrayWriter();
    this.writer = new PrintWriter(buffer);
    this.headers = new HashMap();
  }

  public PrintWriter getWriter() throws IOException {
    return this.writer;
  }

  public void addDateHeader(String s, long l) {
    headers.put(s, new Long(l));
  }

  public void addHeader(String s, String s1) {
    headers.put(s, s1);
  }

  public void addIntHeader(String s, int i) {
    headers.put(s, new Integer(i));
  }

  public void sendRedirect(String s) throws IOException {
    this.redirect = s;
  }

  public void setStatus(int i) {
    this.status = i;
  }

  public void setStatus(int i, String s) {
    this.status = i;
  }

  public void setContentLength(int i) {
    this.contentLength = i;
  }

  public void setContentType(String s) {
    this.contentType = s;
  }

  public void setLocale(Locale l) {
    this.locale = l;
  }

  public void flushBuffer() throws IOException {
    // does nothing because this commits the response back to the client and
    // because we are testing, we don't want the content to be sent back
  }

  public String getContent() {
    return buffer.toString();
  }

  public String getRedirect() {
    return this.redirect;
  }

}