/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.tagext.assertion;

import java.lang.reflect.Constructor;
import java.util.HashMap;

import org.tagunit.TestContextContainer;
import org.tagunit.tagext.ParameterisedTag;
import org.tagunit.test.CustomTestPackage;
import org.tagunit.test.TestPackage;

/**
 * A tag handler that, instead of simply running a predefined test package,
 * instantiates and executes a user defined test package - a class implementing
 * the org.tagunit.test.CustomTestPackage class.
 *
 * @author    Simon Brown
 */
public class AssertCustomTag extends AssertTag implements ParameterisedTag {

  /** the fully qualified classname of the custonm test package */
  private String type;

  /** a map to hold the parameters to this tag (if any) */
  private HashMap parameters;

  /**
   * Template method called during doStartTag(). Tags can override this to
   * perform any custom processing.
   *
   * @param testContext   the current test context container
   */
  protected void doStartTag(TestContextContainer testContext) {
    this.parameters = new HashMap();
  }

  /**
   * Sets the name of the class that represents the custom
   * (user defined) assertion.
   *
   * @param s
   */
  public void setType(String s) {
    this.type = s;
  }

  /**
   * Adds a parameter to this tag.
   *
   * @param   name        the name of the parameter
   * @param   value       the value of the parameter
   */
  public void addParameter(String name, Object value) {
    parameters.put(name, value);
  }

  /**
   * Gets the test package containing the actual tests and assertions.
   *
   * @return  a TestPackage instance
   */
  protected TestPackage getTestPackage() throws Exception {
    // use Java's reflection mechanism to instantiate the custom test package
    CustomTestPackage testPackage = null;

    Class c = Class.forName(type);
    Constructor con = c.getDeclaredConstructor(new Class[]{String.class});
    testPackage = (CustomTestPackage)con.newInstance(new Object[]{getName()});
    testPackage.setParameters(this.parameters);

    return testPackage;
  }

}