/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.tagext.assertion;

import org.tagunit.TestContextContainer;


/**
 * Base class for tags that performs an assertion on two pieces of text.
 *
 * @author    Simon Brown
 */
public abstract class AssertStringComparisonTag extends AssertTag {

  /** a flag to indicate whether whitespace is to be ignored */
  protected boolean ignoreWhitespace = true;

  /** the actual result that was generated */
  protected String actualResult = "";

  /** the expected result to compare the actual against */
  protected String expectedResult = "";

  /**
   * Template method called during doStartTag(). Tags can override this to
   * perform any custom processing.
   *
   * @param testContext   the current test context container
   */
  protected void doStartTag(TestContextContainer testContext) {
    super.doStartTag(testContext);

    // reinitialise these before the test (this is useful when custom tag
    // handler instances are pooled rather than recreated each time)
    this.actualResult = "";
    this.expectedResult = "";
  }

  /**
   * Setter for the ignoreWhitespace attribute.
   *
   * @param   b       true if whitespace should be ignored, false otherwise
   */
  public void setIgnoreWhitespace(boolean b) {
    this.ignoreWhitespace = b;
  }

  /**
   * Sets the actual result that was generated as a part of the test.
   *
   * @param s     a String representing the actual result
   */
  void setActualResult(String s) {
    this.actualResult = s;
  }

  /**
   * Sets the expected result.
   *
   * @param s     a String representing the expected result
   */
  void setExpectedResult(String s) {
    this.expectedResult = s;
  }

}