/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.tagext.test;

import org.tagunit.*;

/**
 * Allows a resource containing other tests to be included.
 *
 * @author    Simon Brown
 */
public class IncludeTestContextTag extends TestContextTag {

  /** the URI of the test(s) to be included */
  private String uri;

  /**
   * Template method called during doStartTag(). Tags can override this to
   * perform any custom processing.
   *
   * @param testContext   the current test context container
   */
  protected void doStartTag(TestContextContainer testContext) {
    DefaultTestContext includedTestContext = new DefaultTestContext(getName() + " (included from " + uri + ")");

    try {
      getTestContextManager().startTestContext(includedTestContext);
      pageContext.include(uri);
    } catch (Exception e) {
      includedTestContext.setStatus(TestContext.ERROR);
      includedTestContext.setMessage(e.getMessage());
    } finally {
      getTestContextManager().endTestContext(includedTestContext);
    }
  }

  /**
   * Sets the URI to the location of the test(s) to be included.
   *
   * @param s   the URI as a String
   */
  public void setUri(String s) {
    this.uri = s;
  }

}