/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.test;

import javax.servlet.jsp.PageContext;

import org.tagunit.TestContext;
import org.tagunit.TestContextContainer;

/**
 * Asserts that a named (and optionally, scoped) page context attribute
 * doesn't exist.
 *
 * @author    Simon Brown
 */
public class NoPageContextAttributeTestPackage extends AbstractTestPackage {

  private String name;
  private String scope;

  /**
   * Creates a new test package for the specified tag.
   */
  public NoPageContextAttributeTestPackage(String name, String scope) {
    this.name = name;
    this.scope = scope;
  }

  /**
   * Runs the tests that are part of this test package.
   *
   * @param testContext   the TestContext to which these tests are to be run
   */
  public void executeTest(TestContextContainer testContext) {
    Object variable = getAttribute();

    // first of all find the named attribute
    if (variable != null) {
      testContext.setMessage("PageContext attribute named " + name + " exists.");
      testContext.setStatus(TestContext.FAIL);
    } else {
      testContext.setStatus(TestContext.PASS);
    }
  }

  /**
   * Helper method to find a named, scoped attribute.
   *
   * @return  an Object attribute
   */
  private Object getAttribute() {
    if (scope == null) {
      // scope isn't specified so just look in all scopes
      return getPageContext().findAttribute(name);
    } else if (scope.equalsIgnoreCase("request")) {
      return getPageContext().getAttribute(name, PageContext.REQUEST_SCOPE);
    } else if (scope.equalsIgnoreCase("page")) {
      return getPageContext().getAttribute(name, PageContext.PAGE_SCOPE);
    } else if (scope.equalsIgnoreCase("session")) {
      return getPageContext().getAttribute(name, PageContext.SESSION_SCOPE);
    } else if (scope.equalsIgnoreCase("application")) {
      return getPageContext().getAttribute(name, PageContext.APPLICATION_SCOPE);
    } else {
      // scope incorrectly specified so just look in all scopes
      return getPageContext().findAttribute(name);
    }
  }

  /**
   * Gets the name of this test package.
   *
   * @return  the name of this test package as a String
   */
  public String getName() {
    if (scope == null) {
      return "Non-existence of PageContext attribute named " + name;
    } else {
      return "Non-existence of PageContext attribute named " + name + " (scope=" + scope + ")";
    }
  }

}