/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit;

import junit.framework.TestCase;

/**
 * Test cases for the DefaultTestContext class.
 *
 * @author      Simon Brown
 */
public class DefaultTestContextTest extends TestCase {

  private DefaultTestContext context;

  public void setUp() {
    context = new DefaultTestContext();
    TagUnitProperties.getInstance().setIgnoreWarnings(false);
  }

  /**
   * Tests the initial values of the bean properties after construction.
   */
  public void testConstruction() {
    // the framework assumes that if the result of a TestContext hasn't been
    // set, then getResult() will return false indicating that the tests
    // failed
    assertEquals(false, context.getResult());

    context = new DefaultTestContext("This is the name");
    assertEquals("This is the name", context.getName());
  }

  /**
   * Tests the setters and getters.
   **/
  public void testSettersAndGetters() {
    context.setName("This is the name");
    assertEquals("This is the name", context.getName());

    context.setMessage("This is the message");
    assertEquals("This is the message", context.getMessage());

    context.setStatus(TestContext.PASS);
    assertEquals(true, context.getResult());
    assertEquals(TestContext.PASS, context.getStatus());

    context.setType(TestContext.MANUAL_TEST);
    assertEquals(TestContext.MANUAL_TEST, context.getType());

    context.setTime(12345);
    assertEquals(12345, context.getTime());
  }

  /**
   * Tests the status of a DefaultTestContext.
   **/
  public void testResult() {
    context.setStatus(TestContext.PASS);
    assertEquals(true, context.getResult());
    assertEquals(TestContext.PASS, context.getStatus());

    context.setStatus(TestContext.WARNING);
    assertEquals(true, context.getResult());
    assertEquals(TestContext.WARNING, context.getStatus());

    context.setStatus(TestContext.FAIL);
    assertEquals(false, context.getResult());
    assertEquals(TestContext.FAIL, context.getStatus());

    context.setStatus(TestContext.ERROR);
    assertEquals(false, context.getResult());
    assertEquals(TestContext.ERROR, context.getStatus());
  }

  public void testParent() {
    DefaultTestContextContainer container = new DefaultTestContextContainer();
    context.setParent(container);
    assertEquals(container, context.getParent());
  }

  public void testIgnoreWarnings() {
    TagUnitProperties.getInstance().setIgnoreWarnings(false);
    context.setStatus(TestContext.WARNING);
    assertEquals(TestContext.WARNING, context.getStatus());

    TagUnitProperties.getInstance().setIgnoreWarnings(true);
    context.setStatus(TestContext.WARNING);
    assertEquals(TestContext.PASS, context.getStatus());
  }

}