/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit;

import junit.framework.TestCase;
import org.tagunit.taginfo.TagInfo;
import org.tagunit.taginfo.TagLibraryInfo;

/**
 * Test cases for the TagLibraryTestContext class.
 *
 * @author      Simon Brown
 */
public class TagLibraryTestContextTest extends TestCase {

  private TagLibraryTestContext tagLibraryContext;

  /**
   * Performs initialization before a test.
   */
  public void setUp() {
    tagLibraryContext = new TagLibraryTestContext();
  }

  /**
   * Tests the initial values of the object after construction.
   */
  public void testConstruction() {
    TagLibraryInfo tagLibraryInfo = new TagLibraryInfo();
    tagLibraryContext = new TagLibraryTestContext(tagLibraryInfo);
    assertSame(tagLibraryInfo, tagLibraryContext.getTagLibraryInfo());
  }

  /**
   * Tests the setters and getters.
   **/
  public void testSettersAndGetters() {
    tagLibraryContext.setName("This is the name");
    assertEquals("This is the name", tagLibraryContext.getName());

    TagLibraryInfo tagLibraryInfo = new TagLibraryInfo();
    tagLibraryContext.setTagLibraryInfo(tagLibraryInfo);
    assertEquals(tagLibraryInfo, tagLibraryContext.getTagLibraryInfo());
  }

  /**
   * Tests that children can be added to a TagLibraryTestContext.
   */
  public void testChildren() {
    // check that there are no children
    assertEquals(0, tagLibraryContext.getChildren().size());
    assertEquals(false, tagLibraryContext.hasChildren());

    // now add a child context and check it gets added to the container
    DefaultTestContext context = new DefaultTestContext();
    tagLibraryContext.add(context);
    assertEquals(1, tagLibraryContext.getChildren().size());
    assertEquals(true, tagLibraryContext.hasChildren());

    // now add another
    TagTestContext tagContext = new TagTestContext();
    TagInfo tagInfo = new TagInfo();
    tagContext.setTagInfo(tagInfo);
    tagInfo.setName("This is the name");
    tagLibraryContext.add(tagContext);
    assertEquals(2, tagLibraryContext.getChildren().size());
    assertEquals(true, tagLibraryContext.hasChildren());
  }

  /**
   * Tests that a TagTestContext can be located when requsted.
   */
  public void testExistingTagTestContext() {
    TagTestContext tagContext = new TagTestContext();
    TagInfo tagInfo = new TagInfo();
    tagContext.setTagInfo(tagInfo);
    tagInfo.setName("This is the name");
    tagLibraryContext.add(tagContext);

    assertEquals(tagContext, tagLibraryContext.getTagTestContext(tagInfo));
  }

  /**
   * Tests that a new TagTestContext gets created when requested.
   */
  public void testNewTagTestContext() {
    TagInfo tagInfo = new TagInfo();
    tagInfo.setName("This is the name");
    assertNotNull(tagLibraryContext.getTagTestContext(tagInfo));
  }

}