/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.taginfo;

import junit.framework.TestCase;
import org.tagunit.*;

/**
 * Test cases for the TagLibraryInfo class.
 *
 * @author      Simon Brown
 */
public class TagLibraryInfoTest extends TestCase {

  private TagLibraryInfo taglib;

  public void setUp() {
    taglib = new TagLibraryInfo();
  }

  /**
   * Tests the initial values of the bean properties after construction.
   */
  public void testConstruction() {
    assertEquals(0, taglib.getTags().size());
  }

  /**
   * Tests the setters and getters.
   **/
  public void testSettersAndGetters() {
    taglib.setJspVersion("1.2");
    assertEquals("1.2", taglib.getJspVersion());

    taglib.setVersion("1.0");
    assertEquals("1.0", taglib.getVersion());

    taglib.setUri("http://www.tagunit.org");
    assertEquals("http://www.tagunit.org", taglib.getUri());

    taglib.setShortName("tagunit");
    assertEquals("tagunit", taglib.getShortName());

    taglib.setDescription("A description for the taglib");
    assertEquals("A description for the taglib", taglib.getDescription());
  }

  /**
   * Tests that a tag can be added to the taglib.
   */
  public void testAddTag() {
    TagInfo tag = new TagInfo();
    tag.setName("myTag");

    try {
      taglib.add(tag);
      assertEquals(1, taglib.getTags().size());
      assertSame(tag, taglib.getTag("myTag"));
    } catch (DuplicateTagException e) {
      fail("Exception throw : " + e.getMessage());
    }
  }

  /**
   * Tests that a tag can be added to the taglib.
   */
  public void testAddDuplicateTag() {
    TagInfo tag = new TagInfo();
    tag.setName("myTag");

    try {
      taglib.add(tag);
      taglib.add(tag);
      fail("Exception not throw - duplicate tag added");
    } catch (DuplicateTagException e) {
    }
  }

}