/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.test;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspTagException;

import junit.framework.TestCase;
import org.tagunit.DefaultTestContextContainer;

/**
 * Test cases for the ExceptionTestPackage class.
 *
 * @author      Simon Brown
 */
public class ExceptionTestPackageTest extends TestCase {

  /**
   * Tests correct behaviour when an exception isn't thrown.
   */
  public void testNoExceptionThrown() {
    // test that any exception was thrown
    ExceptionTestPackage testPackage = new ExceptionTestPackage();
    DefaultTestContextContainer context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());

    // now we're testing for a named exception
    testPackage = new ExceptionTestPackage("javax.servlet.jsp.JspException");
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());
  }

  /**
   * Tests the type of a thrown exception.
   */
  public void testExceptionThrown() {
    // test that any exception was thrown
    ExceptionTestPackage testPackage = new ExceptionTestPackage();
    DefaultTestContextContainer context = new DefaultTestContextContainer();
    testPackage.setThrowable(new JspException());
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());

    // now we're testing for a named exception
    testPackage = new ExceptionTestPackage("javax.servlet.jsp.JspException");
    context = new DefaultTestContextContainer();
    testPackage.setThrowable(new JspException());
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());

    // and again, but with a superclass
    testPackage = new ExceptionTestPackage("javax.servlet.jsp.JspException");
    context = new DefaultTestContextContainer();
    testPackage.setThrowable(new JspTagException());
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());

    // and again, but with a subclass
    testPackage = new ExceptionTestPackage("javax.servlet.jsp.JspTagException");
    context = new DefaultTestContextContainer();
    testPackage.setThrowable(new JspException());
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());

    // and again, but with an incorrect exception type
    testPackage = new ExceptionTestPackage("java.io.IOException");
    context = new DefaultTestContextContainer();
    testPackage.setThrowable(new JspException());
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());
  }

  /**
   * Tests that the message of a thrown exception matches.
   */
  public void testMessage() {
    // test that any exception was thrown
    ExceptionTestPackage testPackage = new ExceptionTestPackage("javax.servlet.jsp.JspException", "This is an error message.");
    DefaultTestContextContainer context = new DefaultTestContextContainer();
    testPackage.setThrowable(new JspException());
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());

    testPackage = new ExceptionTestPackage("javax.servlet.jsp.JspTagException", "This is an error message.");
    context = new DefaultTestContextContainer();
    testPackage.setThrowable(new JspTagException("This is an error message."));
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());
  }

}