<%@ taglib uri="http://www.tagunit.org/tagunit/core" prefix="tagunit" %>
<%@ taglib prefix="c" uri="http://java.sun.com/jstl/core" %>

<%-- syntax 2 : with body content to specify query string parameters --%>

<tagunit:assertEquals name="Simple static URL">
  <tagunit:actualResult><c:url value="relative.jsp"><c:param name="param1" value="value1"/></c:url></tagunit:actualResult>
  <tagunit:expectedResult>relative.jsp?param1=value1</tagunit:expectedResult>
</tagunit:assertEquals>
  
<tagunit:assertEquals name="Simple static relative URL">
  <tagunit:actualResult><c:url value="/relative.jsp"><c:param name="param1" value="value1"/></c:url></tagunit:actualResult>
  <tagunit:expectedResult>/tagunit-examples/relative.jsp?param1=value1</tagunit:expectedResult>
</tagunit:assertEquals>
  
<tagunit:assertEquals name="Simple static absolute URL">
  <tagunit:actualResult><c:url value="http://java.sun.com"><c:param name="param1" value="value1"/></c:url></tagunit:actualResult>
  <tagunit:expectedResult>http://java.sun.com?param1=value1</tagunit:expectedResult>
</tagunit:assertEquals>
  
<c:set var="dynamicUrl" value="relative.jsp"/>
<tagunit:assertEquals name="Simple dynamic relative URL">
  <tagunit:actualResult><c:url value="${dynamicUrl}"><c:param name="param1" value="value1"/></c:url></tagunit:actualResult>
  <tagunit:expectedResult>relative.jsp?param1=value1</tagunit:expectedResult>
</tagunit:assertEquals>
  
<tagunit:assertEquals name="URL in another context (static)">
  <tagunit:actualResult><c:url value="/relative.jsp" context="/another"><c:param name="param1" value="value1"/></c:url></tagunit:actualResult>
  <tagunit:expectedResult>/another/relative.jsp?param1=value1</tagunit:expectedResult>
</tagunit:assertEquals>
  
<c:set var="dynamicContext" value="/another"/>
<tagunit:assertEquals name="URL in another context (dynamic)">
  <tagunit:actualResult><c:url value="/relative.jsp" context="${dynamicContext}"><c:param name="param1" value="value1"/></c:url></tagunit:actualResult>
  <tagunit:expectedResult>/another/relative.jsp?param1=value1</tagunit:expectedResult>
</tagunit:assertEquals>

<tagunit:assertEquals name="Simple URL exported to var (no output)">
  <tagunit:actualResult><c:url value="relative.jsp" var="myUrl"><c:param name="param1" value="value1"/></c:url></tagunit:actualResult>
  <tagunit:expectedResult/>
</tagunit:assertEquals>
<tagunit:assertPageContextAttribute name="myUrl" type="java.lang.String" value="relative.jsp?param1=value1"/>

<tagunit:assertEquals name="Simple URL exported to var in request scope (no output)">
  <tagunit:actualResult><c:url value="relative.jsp" var="myUrlInRequest" scope="request"><c:param name="param1" value="value1"/></c:url></tagunit:actualResult>
  <tagunit:expectedResult/>
</tagunit:assertEquals>
<tagunit:assertPageContextAttribute name="myUrlInRequest" type="java.lang.String" value="relative.jsp?param1=value1" scope="request"/>

<tagunit:assertEquals name="Simple URL exported to var in page scope (no output)">
  <tagunit:actualResult><c:url value="relative.jsp" var="myUrlInPage" scope="page"><c:param name="param1" value="value1"/></c:url></tagunit:actualResult>
  <tagunit:expectedResult/>
</tagunit:assertEquals>
<tagunit:assertPageContextAttribute name="myUrlInPage" type="java.lang.String" value="relative.jsp?param1=value1" scope="page"/>

<tagunit:assertEquals name="Simple URL exported to var in session scope (no output)">
  <tagunit:actualResult><c:url value="relative.jsp" var="myUrlInSession" scope="session"><c:param name="param1" value="value1"/></c:url></tagunit:actualResult>
  <tagunit:expectedResult/>
</tagunit:assertEquals>
<tagunit:assertPageContextAttribute name="myUrlInSession" type="java.lang.String" value="relative.jsp?param1=value1" scope="session"/>

<tagunit:assertEquals name="Simple URL exported to var in application scope (no output)">
  <tagunit:actualResult><c:url value="relative.jsp" var="myUrlInApplication" scope="application"><c:param name="param1" value="value1"/></c:url></tagunit:actualResult>
  <tagunit:expectedResult/>
</tagunit:assertEquals>
<tagunit:assertPageContextAttribute name="myUrlInApplication" type="java.lang.String" value="relative.jsp?param1=value1" scope="application"/>

  
